﻿using Infragistics.Web.UI;
using Infragistics.Web.UI.GridControls;
using System;
using System.Data;
using System.Web.UI;
using System.Web.UI.WebControls;

namespace WHDG.АddDynamicCheckboxColumns
{
    public partial class Default : System.Web.UI.Page
    {
        private static DataSet ds;

        public Default()
        {
            if (ds == null) ds = GetDataSource();
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            whdg.DataSource = ds;

            if (!IsPostBack)
            {
                GenerateBoundFieldColumn();
                GenerateTemplatedColumn();
                whdg.GroupingSettings.GroupedColumns.Add("Category");
                whdg.GroupingSettings.GroupAreaVisibility = Visibility.Hidden;
            }
        }

        private DataSet GetDataSource()
        {
            DataSet ds = new DataSet("Set");
            ds.Tables.Add(GetParentData());
            return ds;
        }

        public DataTable GetParentData()
        {
            DataTable dt = new DataTable("ParentTable");
            dt.Columns.Add("ID", typeof(int));
            dt.Columns.Add("Category", typeof(string));
            dt.Columns.Add("Series", typeof(string));
            dt.Columns.Add("Value", typeof(double));
            dt.Columns.Add("TemplatedColumn", typeof(bool));

            string[] Categories = { "Category A", "Category B", "Category C", "Category D" };
            Random rnd = new Random();

            for (int i = 0; i < 10; i++)
            {
                string category = Categories[rnd.Next(0, 4)];
                int series = rnd.Next(1, 4);
                int number = rnd.Next(1000, 3000);

                dt.Rows.Add(new object[] { i, category, "Series " + series, number, number > 2000 });
            }
            return dt;
        }

        public void GenerateTemplatedColumn()
        {
            TemplateDataField templateCol = new TemplateDataField();
            templateCol.Key = "TemplatedColumn";
            templateCol.Header.Text = "Over 2000";
            templateCol.Width = Unit.Percentage(18);

            whdg.Columns.Add(templateCol);
        }

        public void GenerateBoundFieldColumn()
        {
            BoundDataField boundCategory = new BoundDataField();
            boundCategory.Key = "Category";
            boundCategory.Header.Text = "Category";
            boundCategory.Width = Unit.Percentage(18);

            BoundDataField boundValue = new BoundDataField();
            boundValue.Key = "Value";
            boundValue.Header.Text = "Value";
            boundValue.Width = Unit.Percentage(18);

            BoundDataField boundID = new BoundDataField();
            boundID.Key = "ID";
            boundID.Header.Text = "ID";
            boundID.Hidden = false;
            boundID.Width = Unit.Percentage(10);

            whdg.Columns.Add(boundID);
            whdg.Columns.Add(boundCategory);
            whdg.Columns.Add(boundValue);
        }

        protected void whdg_InitializeRow(object sender, RowEventArgs e)
        {
            e.Row.Items.FindItemByKey("TemplatedColumn").Template = new CustomItemTemplate();
        }

        public static object GetWebGridControl(Infragistics.Web.UI.GridControls.GridRecord row, string cntName, string templateName = null)
        {
            if (templateName != null)
                return row.Items.FindItemByKey(templateName).FindControl(cntName);
            else
                return row.Items.FindItemByKey(cntName).Value;
        }

        protected void btn_Click(object sender, EventArgs e)
        {
            whdg.EnsureTemplates();
        }

        private class CustomItemTemplate : ITemplate
        {
            public void InstantiateIn(Control container)
            {
                string columnKey = (((GridRecordItem)(((TemplateContainer)container).Item)).Column).Key;

                CheckBox checkbox = new CheckBox();
                checkbox.ID = "chk-" + columnKey;
                checkbox.Checked = (bool)DataBinder.Eval(((TemplateContainer)container).DataItem, columnKey);
                checkbox.Enabled = false;

                container.Controls.Add(checkbox);
            }
        }
    }
}